From ed2e69234b90c31d70958c43457349e08a7df7a1 Mon Sep 17 00:00:00 2001
From: Tamas Gal <tgal@km3net.de>
Date: Wed, 30 Sep 2020 22:40:05 +0200
Subject: [PATCH] Moving on

---
 km3io/tools.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/km3io/tools.py b/km3io/tools.py
index 5855c52..79291b9 100644
--- a/km3io/tools.py
+++ b/km3io/tools.py
@@ -335,10 +335,10 @@ def best_track(tracks, strategy="default", reco=None):
             rec_stage_max_idx = np.iinfo(np.int32).max
 
         if n_events == 1:
-            raise NotImplementedError
             # first mask to select those with the correct reconstruction type
             rec_types = tracks[tracks.rec_type == reconstruction[rec_type]]
-            # TODO: check if rec_stages are all between rec_stage_min_idx and rec_stage_max_idx
+            # TODO: select tracks where rec_stages are all between rec_stage_min_idx and rec_stage_max_idx
+            tracks = tracks[]
             len_stages = count_nested(rec_types.rec_stages, axis=1)
             # TODO:  etc.
             longest = rec_types[len_stages == ak1.max(len_stages, axis=0)]
-- 
GitLab